@@ -10,33 +10,18 @@
 // Added seed HTML to make it easier to start editing the page.
 // Revised: 2/7/2012	ELL
 // Added table prefix handling.
+// Revised: 6/24/2013	ELL
+// Added ability to specify meaningful names.
 	
 	include ("check_session.php");
 		
 	$area_type = $_REQUEST['area_type'];
-	
-	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name LIKE '". $area_type . "%' ORDER BY page_name DESC";
-	$result = $bwb_dbh->query($query);
-	$row = $result->fetch(PDO::FETCH_ASSOC);
-	$page_name = $row["page_name"];
-	
-	if ($page_name == $area_type)
-		$special_page_name = $area_type . "1";
+	$suffix = $_REQUEST['suffix'];
+	if (is_numeric($suffix))
+		$special_page_name = $area_type . $suffix;
 	else
-	{
-		$index = array();
-		$i = 1;
-		$index[0] = substr($page_name, strlen($area_type));
-		while ($row = $result->fetch(PDO::FETCH_ASSOC))
-		{
-			$page_name = $row["page_name"];
-			$index[$i] = substr($page_name, strlen($area_type));
-			$i++;
-		}
-		sort($index);
-		$index[$i-1] = $index[$i-1] + 1;
-		$special_page_name = $area_type . $index[$i-1];
-	}
+		$special_page_name = $area_type . "_" . $suffix;
+	
 	$body_html = "\n<p>Enter your content here.</p>\n";
 	$today = date("Y-m-d H:i:s");
 	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='" . $special_page_name . "', page_content='" . $body_html . "', revised='" . $today . "'";
