@@ -22,6 +22,8 @@
 // Added class/ID dropdown for automatically prefixing class string.
 // Revised: 2/18/2013	ELL
 // Added checkbox for creating link set.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
 // 
 	include ("check_session.php");
 		
@@ -78,7 +80,8 @@
 
 <script type="text/javascript" src="js/json2.js"></script>
 <script type="text/javascript" src="js/ajax.js"></script>
-
+<script type="text/javascript" src="js/mouse_position.js"></script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
 <script type="text/javascript" src="js/classes.js"></script>
 
 <script language="javascript" type="text/javascript">
@@ -86,7 +89,7 @@ function DeleteClass()
 {
 	var class_delete = document.getElementById("class_delete").value;
 	class_delete = EscapeClass(class_delete);
-	document.getElementById("delete_confirm").style.display = "none";
+	HidePopupMsg();
 	var url = "delete_class.php?class=" + class_delete + "&style_sheet=<?php echo $style_sheet; ?>";
 	window.location = url;
 }
@@ -342,18 +345,10 @@ function UpdateDescription()
 </table>
 </div>
 
-<div id="delete_confirm">
-<table border="0" cellspacing="0" cellpadding="5" align="center">
-  <tr>
-    <td colspan="2">Are your sure you want to delete the class <b><div id="delete_text">&nbsp;</div></b>?</td>
-  </tr>
-  <tr>
-	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeleteClass();" /></td>
-	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();" />
-    </td>
-  </tr>
-</table>
-</div>
+<?php include("lib/popup_msg.html"); ?>
 
+<script language="javascript" type="text/javascript">
+	HidePopupMsg();
+</script>
 </body>
 </html>
