@@ -20,30 +20,29 @@
 		$suffix = substr($menu, 4);
 		
 		/////// Look for JavaScript Menu and remove code if necessary. ///////////////
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus` WHERE `menu_name` = '$menu'";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus` WHERE `menu_name`='" . $menu . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$menu_type = $row["menu_type"];
 		if ($menu_type == 1)
 		{
-			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE `menu_name` = '$menu'";
+			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE `menu_name`='" . $menu . "'";
 			$result = $bwb_dbh->query($query);
 			$row = $result->fetch(PDO::FETCH_ASSOC);
 			$border_area = $row["border_area"];
 			include("remove_menu_code.php");
 		}
-		//////////////////////////////////////////////////////////////////////////////
-		
-		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE `menu_name` = $menu";
+		//////////////////////////////////////////////////////////////////////////////	
+		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE `menu_name`='" . $menu . "'";
+		$cnt = $bwb_dbh->exec($query);
+
+		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menus` WHERE `menu_name`='" . $menu . "'";
 		$cnt = $bwb_dbh->exec($query);
 		
-		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menus` WHERE `menu_name` = '$menu'";
+		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "style_sheets` WHERE `name`='" . $menu . "'";
 		$cnt = $bwb_dbh->exec($query);
 		
-		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "style_sheets` WHERE `name` = '$menu'";
-		$cnt = $bwb_dbh->exec($query);
-		
-		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "style_sheets` WHERE `name` = '" . $menu . "_item'";
+		$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "style_sheets` WHERE `name`='" . $menu . "_item'";
 		$cnt = $bwb_dbh->exec($query);
 			
 		$query = "DROP TABLE IF EXISTS " . BWB_TABLE_PREFIX . "menu"  . $suffix . "_classes";
