@@ -28,6 +28,8 @@
 // Added 2nd and 3rd fonts, box shadow and border radius.
 // Revised: 5/23/2013	ELL
 // Added clear, min/max prefix for width and height and sticky footer setup button.
+// Revised: 6/28/2013	ELL
+// Implemented popup message class.
 // 
 //
 	include ("check_session.php");
@@ -56,6 +58,7 @@
 
 <script type="text/javascript" src="js/check_color_str.js"></script>
 <script type="text/javascript" src="js/mouse_position.js"></script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
 
 <script type="text/javascript" src="js/edit_css.js"></script>
 
@@ -412,11 +415,13 @@ function UpdateCSS()
 {
 	var params = "";
 	
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		ShowStatusMsg();
-		document.getElementById("StatusMsg").innerHTML = "Starting update...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting update...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+		
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -424,7 +429,7 @@ function UpdateCSS()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg");
+		xmlhttp = UpdateMessage(xmlhttp, false);
 
 		params = "submit=Update";
 		params = params + "&style_sheet=<? echo $style_sheet; ?>";
@@ -1584,14 +1589,11 @@ function UpdateCSS()
 <a name="bottom_anchor"></a>
 </div>
 
-<div id="popup_msg_div">
-<div id="StatusMsg"> </div>
-<img src="images/close-button.png" alt="Close" id="popup_msg_close_btn" onClick="HideStatusMsg();" />
-</div>
+<?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
 	enable_disable_controls(0);
-	HideStatusMsg();
+	HidePopupMsg();
 </script>
 </body>
 </html>
\ No newline at end of file
