@@ -12,6 +12,8 @@
 // Added selection for having sub menus collapse and expand.  Default is to collapse and expand.  New option is to show always expanded.
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Revised: 6/19/2013	ELL
+// Added separate text alignment for sub menus.
 //
 
 	include ("check_session.php");
@@ -228,7 +230,7 @@ Select a menu to add items to:
 	else
 		$menu_width = 100;
 	$menu_width_units = $row["width_units"];
-	$text_align = $row["align"];
+	$top_level_text_align = $row["align"];
 	
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.menu_div" . $suffix . "'";
 	$result = $bwb_dbh->query($query);
@@ -246,6 +248,11 @@ Select a menu to add items to:
 	else
 		$position = "absolute";
 		
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_1_a" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$sub_level_text_align = $row["align"];
+		
 	/////////////////////////////////////////
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus WHERE menu_name = '" . $menu . "'";
 	$result = $bwb_dbh->query($query);
@@ -349,12 +356,12 @@ Select a menu to add items to:
 		</td>
         <td align="right">Text Alignment: </td>
 		<td align="left">
-               <select name="text_align" id="text_align">
+               <select name="top_level_text_align" id="top_level_text_align">
                 <option value="-not selected-">-not selected-</option>
-                <option value="left" <?php if ($text_align == "left") echo "selected='selected'"; ?>>Left</option>
-                <option value="center" <?php if ($text_align == "center") echo "selected='selected'"; ?>>Center</option>
-                <option value="right" <?php if ($text_align == "right") echo "selected='selected'"; ?>>Right</option>
-                <option value="justify" <?php if ($text_align == "justify") echo "selected='selected'"; ?>>Justify</option>
+                <option value="left" <?php if ($top_level_text_align == "left") echo "selected='selected'"; ?>>Left</option>
+                <option value="center" <?php if ($top_level_text_align == "center") echo "selected='selected'"; ?>>Center</option>
+                <option value="right" <?php if ($top_level_text_align == "right") echo "selected='selected'"; ?>>Right</option>
+                <option value="justify" <?php if ($top_level_text_align == "justify") echo "selected='selected'"; ?>>Justify</option>
                </select>
 		</td>
         </tr>
@@ -442,9 +449,19 @@ Select a menu to add items to:
                 <option value="3" <?php if ($sub_level_item_height_units == 3) echo "selected='selected'"; ?>>%</option>
 		        </select>
                 </td>
-                </tr>
-                </table>
-                </td>
+                 <td align="right">Text Alignment: </td>
+				<td align="left">
+               <select name="sub_level_text_align" id="sub_level_text_align">
+                <option value="-not selected-">-not selected-</option>
+                <option value="left" <?php if ($sub_level_text_align == "left") echo "selected='selected'"; ?>>Left</option>
+                <option value="center" <?php if ($sub_level_text_align == "center") echo "selected='selected'"; ?>>Center</option>
+                <option value="right" <?php if ($sub_level_text_align == "right") echo "selected='selected'"; ?>>Right</option>
+                <option value="justify" <?php if ($sub_level_text_align == "justify") echo "selected='selected'"; ?>>Justify</option>
+               </select>
+				</td>
+               </tr>
+              </table>
+             </td>
 		    </tr>
 		  <tr>
 		    <td>
