@@ -17,6 +17,8 @@
 // Added table prefix handling.
 // Revised: 11/8/2012	ELL
 // Added injection of current color for initializing color picker.
+// Revised: 7/21/2013	ELL
+// Added background opacity.
 //
 
 	include ("check_session.php");
@@ -593,7 +595,7 @@ Select a menu to add items to:
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = 'ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
-	if (!is_null($row["text_color"])   && ($row["text_color"] != ""))
+	if (!is_null($row["text_color"]) && ($row["text_color"] != ""))
 		$sub_level_1_text_color_active = $row["text_color"];
 	else
 		$sub_level_1_text_color_active = "-not set-";
@@ -605,6 +607,22 @@ Select a menu to add items to:
 		$top_level_item_border_color_active = $row["border_color"];
 	else
 		$top_level_item_border_color_active = "-not set-";
+		
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.top_level_ul" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	if (!is_null($row["bkgd_opacity"]) && ($row["bkgd_opacity"] > 0))
+		$top_level_background_opacity = $row["bkgd_opacity"];
+	else
+		$top_level_background_opacity = -1;
+		
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_css_table . " WHERE class = '.sub_level_1_ul" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	if (!is_null($row["bkgd_opacity"]) && ($row["bkgd_opacity"] > 0))
+		$sub_level_background_opacity = $row["bkgd_opacity"];
+	else
+		$sub_level_background_opacity = -1;
 ?>
 
 <form name="frm_menu_styles" action="save_css_menu_styles.php" method="post">
@@ -996,10 +1014,10 @@ Select a menu to add items to:
 			<td class="bold">Hover (mouse over)</td>
 			<td class="bold">Active (mouse click)</td>
 			<td class="bold">&nbsp;</td>
-            <td align="center" rowspan="6" valign="bottom" class="bold">T<br>o<br>p</td>
-            <td  align="center" rowspan="6" valign="bottom" class="bold">B<br>o<br>t<br>t<br>o<br>m</td>
-            <td align="center" rowspan="6" valign="bottom" class="bold">L<br>e<br>f<br>t</td>
-            <td  align="center" rowspan="6" valign="bottom" class="bold">R<br>i<br>g<br>h<br>t</td>
+            <td align="center" rowspan="8" valign="bottom" class="bold">T<br>o<br>p</td>
+            <td  align="center" rowspan="8" valign="bottom" class="bold">B<br>o<br>t<br>t<br>o<br>m</td>
+            <td align="center" rowspan="8" valign="bottom" class="bold">L<br>e<br>f<br>t</td>
+            <td  align="center" rowspan="8" valign="bottom" class="bold">R<br>i<br>g<br>h<br>t</td>
 		  </tr>
 		  <tr>
 			<td align="right">Top Level Text Color: </td>
@@ -1036,7 +1054,11 @@ Select a menu to add items to:
 		    <td><span class="small_message">(same as top level)</span></td>
 		    <td>&nbsp;</td>
             
-		    </tr>
+		  </tr>
+          <tr>
+          	<td colspan="4">&nbsp;</td>
+            <td><span class="bold">Opacity</span></td>
+          </tr>
 		  <tr>
 		    <td align="right">Top Level Background Color:</td>
 		    <td><input name="top_level_background_color" type="text" id="top_level_background_color" value="<?php echo $top_level_background_color; ?>" size="10" onBlur="CheckColorString(this);">
@@ -1045,7 +1067,8 @@ Select a menu to add items to:
 		      <span class="small_message"> <a href=# onClick="javascript: popupcolorpicker('frm_menu_styles', 'top_level_background_color_hover');">#RRGGBB</a></span></td>
 		    <td><input name="top_level_background_color_active" type="text" id="top_level_background_color_active" value="<?php echo $top_level_background_color_active; ?>" size="10" onBlur="CheckColorString(this);">
               <span class="small_message"> <a href=# onClick="javascript: popupcolorpicker('frm_menu_styles', 'top_level_background_color_active');">#RRGGBB</a></span></td>
-		    <td>&nbsp;</td>
+		    <td><input name="top_level_background_opacity" type="text" id="top_level_background_opacity" value="<?php echo $top_level_background_opacity; ?>" size="10">
+		    %</td>
             
 		    </tr>
 		  <tr>
@@ -1054,9 +1077,14 @@ Select a menu to add items to:
 		      <span class="small_message"> <a href=# onClick="javascript: popupcolorpicker('frm_menu_styles', 'sub_level_background_color');">#RRGGBB</a></span></td>
 		    <td class="small_message">(same as top level)</td>
 		    <td><span class="small_message">(same as top level)</span></td>
-		    <td><span class="bold">Width</span></td>
+		    <td><input name="sub_level_background_opacity" type="text" id="sub_level_background_opacity" value="<?php echo $sub_level_background_opacity; ?>" size="10">
+		      %</td>
            
 		    </tr>
+          <tr>
+          	<td colspan="4">&nbsp;</td>
+            <td><span class="bold">Width</span></td>
+          </tr>
           <tr>
             <td align="right">Top Level Block Border Color:</td>
             <td><input name="top_level_block_border_color" type="text" id="top_level_block_border_color" value="<?php echo $top_level_block_border_color; ?>" size="10" onBlur="CheckColorString(this);">
