@@ -7,6 +7,11 @@
 // Added 2nd and 3rd fonts, box shadow and border radius.
 // Revised: 5/23/2013	ELL
 // Added clear, min/max prefix for width and height and sticky footer setup button.
+// Revised: 6/28/2013	ELL
+// Implemented popup message class.
+
+var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
+var popup_msg = new PopupMsg(param_array);
 
 function popupcolorpicker(form_name, field_name)
 {
@@ -260,9 +265,12 @@ function enable_disable_controls(ShowMessage)
 	}
 	if (ShowMessage == 1)
 	{
-		ShowStatusMsg();
-		ShowStatusMsgCloseBtn();
-		document.getElementById("StatusMsg").innerHTML = "Click 'Update' to commit changes.";
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = "Click 'Update' to commit changes.";
+		popup_msg.popup_timeout = -1;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 500;
+		popup_msg.ShowPopupMsg();
 	}
 }
 
@@ -326,36 +334,29 @@ function enable_disable_shadow()
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
-function UpdateMessage(xmlhttp, StatusMsg_control_name)
+function UpdateMessage(xmlhttp)
 {
 	xmlhttp.onreadystatechange=function()
 	{
 		if (xmlhttp.readyState==4)
 		{
 			if (xmlhttp.responseText.length > 0)
-				document.getElementById(StatusMsg_control_name).innerHTML = "Update complete: " + xmlhttp.responseText;
+				popup_msg.status_msg = "Update complete: " + xmlhttp.responseText;
 			else
-				document.getElementById(StatusMsg_control_name).innerHTML = "Update complete";
-			var ClearMessageString = "ClearMessage('" + StatusMsg_control_name + "');";
-			mTimer = setTimeout(ClearMessageString, 2000);
+				popup_msg.status_msg = "Update complete";
+			popup_msg.popup_timeout = 2000;
 		}
 		else if (xmlhttp.readyState==1)
-			document.getElementById(StatusMsg_control_name).innerHTML = "Update ready to send...";
+			popup_msg.status_msg = "Update ready to send...";
 		else if (xmlhttp.readyState==2)
-			document.getElementById(StatusMsg_control_name).innerHTML = "Update sent";
+			popup_msg.status_msg = "Update sent";
 		else if (xmlhttp.readyState==3)
-			document.getElementById(StatusMsg_control_name).innerHTML = "Updating...";
+			popup_msg.status_msg = "Updating...";
+		popup_msg.ShowPopupMsg();
 	}
 	return (xmlhttp);
 }
 
-function ClearMessage(StatusMsg_control_name)
-{
-	HideStatusMsg();
-	document.getElementById(StatusMsg_control_name).innerHTML = " ";
-	clearInterval(mTimer);
-}
-
 ////////////////////////////////////////////////////////////////////////////////////
 function LoadCenterParams()
 {
@@ -363,11 +364,12 @@ function LoadCenterParams()
 	
 	var params = "";
 	
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		ShowStatusMsg();
-		document.getElementById("StatusMsg").innerHTML = "Starting update...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting update...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
 		
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
@@ -375,7 +377,7 @@ function LoadCenterParams()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg");
+		xmlhttp = UpdateMessage(xmlhttp);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -394,7 +396,7 @@ function LoadCenterParams()
 	{
 		xmlhttp2.open("POST","save_css.php",true);
 		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp2 = UpdateMessage(xmlhttp2, "StatusMsg");
+		xmlhttp2 = UpdateMessage(xmlhttp2);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -416,9 +418,8 @@ function LoadCenterParams()
 		xmlhttp2.send(params);
 	}
 		
-	alert("Your site has been centered.  You may also want to revise the 'body' width, the 'body' background color, and the '#wrap' backgound color to your needs.");
-	document.getElementById("StatusMsg").innerHTML = "Your site has been centered.  You may want to revise the 'body' width, the 'body' background color, and the '#wrap' backgound color to your needs.";
-	ShowStatusMsgCloseBtn();
+	var msg = "Your site has been centered.  You may want to revise the 'body' width, the 'body' background color, and the '#wrap' backgound color to your needs.";
+	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -428,11 +429,12 @@ function LoadStickyFooterParams()
 	
 	var params = "";
 	
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		ShowStatusMsg();
-		document.getElementById("StatusMsg").innerHTML = "Starting update...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting update...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
 		
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
@@ -440,7 +442,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg");
+		xmlhttp = UpdateMessage(xmlhttp);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -459,7 +461,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp2.open("POST","save_css.php",true);
 		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp2 = UpdateMessage(xmlhttp2, "StatusMsg");
+		xmlhttp2 = UpdateMessage(xmlhttp2);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -483,7 +485,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp3.open("POST","save_css.php",true);
 		xmlhttp3.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp3 = UpdateMessage(xmlhttp3, "StatusMsg");
+		xmlhttp3 = UpdateMessage(xmlhttp3);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -502,7 +504,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp4.open("POST","save_css.php",true);
 		xmlhttp4.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp4 = UpdateMessage(xmlhttp4, "StatusMsg");
+		xmlhttp4 = UpdateMessage(xmlhttp4);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -526,42 +528,22 @@ function LoadStickyFooterParams()
 		xmlhttp4.send(params);
 	}
 		
-	alert("Your footer will now stick to the bottom of the browser window.  You may also want to revise the 'footer' height and the background color to your needs. Be sure to set the footer's margin top to the same but negative of the footer's height.");
-	document.getElementById("StatusMsg").innerHTML = "Your footer will now stick to the bottom of the browser window.  You may also want to revise the 'footer' height and the background color to your needs. Be sure to set the footer's margin top to the same but negative of the footer's height.";
-	ShowStatusMsgCloseBtn();
+	var msg = "Your footer will now stick to the bottom of the browser window.  You may also want to revise the 'footer' height and the background color to your needs. Be sure to set the footer's margin top to the same but negative of the footer's height.";
+	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
+}
+
+function DisplayFinalMsg(msg)
+{
+	popup_msg.status_msg = msg;
+	popup_msg.popup_msg_type = 2;
+	popup_msg.popup_timeout = -1;
+	popup_msg.left_offset = 250;
+	popup_msg.msg_width = 600;
+	popup_msg.ShowPopupMsg();
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
 function OpenHelpWindow()
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_css", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-
-function ShowStatusMsg()
-{
-	var ntop;
-	ntop = tempY;
-	
-	if (ntop < 500)
-		ntop = ntop - 20;
-	else
-		ntop = ntop - 40;
-	var strtop = ntop + "px";
-	
-	document.getElementById("popup_msg_div").style.display = "block";
-	document.getElementById("popup_msg_div").style.position = "absolute";
-	document.getElementById("popup_msg_div").style.top = strtop;
-	document.getElementById("popup_msg_div").style.left = "500px";
-}
-
-function ShowStatusMsgCloseBtn()
-{
-	document.getElementById("popup_msg_close_btn").style.display = "inline";
-}
-
-function HideStatusMsg()
-{
-	document.getElementById("popup_msg_div").style.display = "none";
-	document.getElementById("popup_msg_close_btn").style.display = "none";
-	document.getElementById("StatusMsg").innerHTML = " ";
 }
\ No newline at end of file
