@@ -3,7 +3,15 @@
 // Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created:	3/9/2013	ELL
+// Revised: 5/14/2013	ELL
+// Added URL escaping and unescaping of URL itself.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
 //
+
+var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
+var popup_msg = new PopupMsg(param_array);
+
 function Indent(level)
 {
 	var indent = "";
@@ -23,40 +31,33 @@ function OpenHelpWindow()
 ////////////////////////////////////////////////////////////////////////////////////////////
 function DeleteConfirm(item_text, ID, i)
 {
-	var ntop;
-	ntop = tempY;
-	if (ntop < 500)
-		ntop = ntop + 20;
-	else
-		ntop = ntop - 20;
-	var strtop = ntop + "px";
-	
-	document.getElementById("delete_confirm").style.display = "block";
-	document.getElementById("delete_confirm").style.position = "absolute";
-	document.getElementById("delete_confirm").style.top = strtop;
-	document.getElementById("delete_confirm").style.left = "200px";
-	document.getElementById("delete_confirm").style.width = "450px";
-	document.getElementById("delete_confirm").style.backgroundColor = "#FFF";
-	document.getElementById("delete_confirm").style.borderStyle = "solid";
-	document.getElementById("delete_confirm").style.borderWidth = "2px";
-	document.getElementById("delete_confirm").style.borderColor = "#000";
-	document.getElementById("delete_text").innerHTML = item_text;
-	document.getElementById("menu_item_to_delete").value = ID;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 300;
+	popup_msg.popup_msg_type = 3;
+	popup_msg.popup_btn_cnt = 2;
+	popup_msg.popup_msg_cell = "Are you sure you want to delete the <b>" + item_text + "</b> menu item?";
+	popup_msg.popup_button_2_span = "Yes";
+	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_timeout = -1;
+	popup_msg.ShowPopupMsg();
+	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenuItem(ID); };
+	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
 }
 
-function DeleteMenuItem()
+function DeleteMenuItem(IDRemove)
 {
 	var params = "";
-	var IDRemove = document.getElementById("menu_item_to_delete").value;
 
-	document.getElementById("delete_confirm").style.display = "none";
+	HidePopupMsg();
 	menu = document.getElementById("selectMenu").value;
 	
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		document.getElementById("StatusMsg").innerHTML = "Starting delete...";
-		document.getElementById("StatusMsg2").innerHTML = "Starting delete...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting delete...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+	
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -64,7 +65,7 @@ function DeleteMenuItem()
 	{
 		xmlhttp.open("POST","delete_menu_item.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg", "Delete");
+		xmlhttp = UpdateMessage(xmlhttp, "Delete");
 		
 		params = "menu=" + document.getElementById("selectMenu").value;
 		params = params + "&IDRemove=" + IDRemove;
@@ -73,11 +74,6 @@ function DeleteMenuItem()
 	}
 }
 
-function HideDelete()
-{
-	document.getElementById("delete_confirm").style.display = "none";
-}
-
 //////////////////////////////////////////////////////////////////////////////////////
 function UpdateMenuItem(ID, i)
 {
@@ -95,12 +91,15 @@ function UpdateMenuItem(ID, i)
 	var target_ctl = "target" + i;
 	var sort_order_ctl = "sort_order" + i;
 	var item_text = "";
+	var URL = "";
 
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		document.getElementById("StatusMsg").innerHTML = "Starting update...";
-		document.getElementById("StatusMsg2").innerHTML = "Starting update...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting update...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+	
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -108,17 +107,19 @@ function UpdateMenuItem(ID, i)
 	{
 		xmlhttp.open("POST","update_menu_item.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg", "Update");
+		xmlhttp = UpdateMessage(xmlhttp, "Update");
 		
 		// Escape URL string
 		item_text = document.getElementById(item_text_ctl).value;
 		item_text = EscapeURL(item_text);
+		URL = document.getElementById(URL_ctl).value;
+		URL = EscapeURL(URL);
 		
 		params = "menu=" + document.getElementById("selectMenu").value;
 		params = params + "&ID=" + ID;
 		params = params + "&item_text=" + item_text;
 		params = params + "&level=" + document.getElementById(level_ctl).value;
-		params = params + "&URL=" + document.getElementById(URL_ctl).value;
+		params = params + "&URL=" + URL;
 		params = params + "&target=" + document.getElementById(target_ctl).value;
 		params = params + "&sort_order=" + document.getElementById(sort_order_ctl).value;
 		//alert(params);
@@ -137,12 +138,15 @@ function UpdateAll()
 	var target_ctl;
 	var sort_order_ctl;
 	var item_text;
+	var URL;
 
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		document.getElementById("StatusMsg").innerHTML = "Starting update...";
-		document.getElementById("StatusMsg2").innerHTML = "Starting update...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Starting update...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+	
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -150,7 +154,7 @@ function UpdateAll()
 	{
 		xmlhttp.open("POST","save_menu_items.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg", "UpdateAll");
+		xmlhttp = UpdateMessage(xmlhttp, "UpdateAll");
 		
 		params = "menu=" + document.getElementById("selectMenu").value;
 		var cnt = document.getElementById("nCount").value;
@@ -170,7 +174,9 @@ function UpdateAll()
 			item_text = EscapeURL(item_text);
 			params = params + "&item_text" + i + "=" + item_text;
 			params = params + "&level" + i + "=" + document.getElementById(level_ctl).value;
-			params = params + "&URL" + i + "=" + document.getElementById(URL_ctl).value;
+			URL = document.getElementById(URL_ctl).value;
+			URL = EscapeURL(URL);
+			params = params + "&URL" + i + "=" + URL;
 			params = params + "&target" + i + "=" + document.getElementById(target_ctl).value;
 			params = params + "&sort_order" + i + "=" + document.getElementById(sort_order_ctl).value;
 		}
@@ -181,9 +187,8 @@ function UpdateAll()
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
-function UpdateMessage(xmlhttp, StatusMsg_control_name, Source)
+function UpdateMessage(xmlhttp, Source)
 {
-	var StatusMsg_control_name2 = StatusMsg_control_name + "2";
 	var query_complete_no_record = "Query complete.  No records found.";
 	var query_complete = "<b>Query complete<\/b><br/>\n";
 	var query_read_to_send = "Query ready to send...";
@@ -217,55 +222,29 @@ function UpdateMessage(xmlhttp, StatusMsg_control_name, Source)
 				var rows_str = xmlhttp.responseText;
 //				alert(rows_str);
 				if (rows_str == "-no data-")
-				{
-					document.getElementById(StatusMsg_control_name).innerHTML = query_complete_no_record;
-					document.getElementById(StatusMsg_control_name2).innerHTML = query_complete_no_record;
-				}
+					popup_msg.status_msg = query_complete_no_record;
 				else
-				{
-					document.getElementById(StatusMsg_control_name).innerHTML = query_complete;
-					document.getElementById(StatusMsg_control_name2).innerHTML = query_complete;
-				}
+					popup_msg.status_msg = query_complete;
 				if ((Source == "Populate") || (Source == "Delete") || (Source == "UpdateAll"))
 					PopulateTable(rows_str);
 			}
 			else
-			{
-				document.getElementById(StatusMsg_control_name).innerHTML = query_complete_no_record;
-				document.getElementById(StatusMsg_control_name2).innerHTML = query_complete_no_record;
-			}
+				popup_msg.status_msg = query_complete_no_record;
 
-			var ClearMessageString = "ClearMessage('" + StatusMsg_control_name + "');";
-			mTimer = setTimeout(ClearMessageString, 2000);
+			popup_msg.popup_timeout = 2000;
 		}
 		else if (xmlhttp.readyState==1)
-		{
-			document.getElementById(StatusMsg_control_name).innerHTML = query_read_to_send;
-			document.getElementById(StatusMsg_control_name2).innerHTML = query_read_to_send;
-		}
+			popup_msg.status_msg = query_read_to_send;
 		else if (xmlhttp.readyState==2)
-		{
-			document.getElementById(StatusMsg_control_name).innerHTML = query_sent;
-			document.getElementById(StatusMsg_control_name2).innerHTML = query_sent;
-		}
+			popup_msg.status_msg = query_sent;
 		else if (xmlhttp.readyState==3)
-		{
-			document.getElementById(StatusMsg_control_name).innerHTML = query_starting;
-			document.getElementById(StatusMsg_control_name2).innerHTML = query_starting;
-		}
+			popup_msg.status_msg = query_starting;
+			
+		popup_msg.ShowPopupMsg();
 	}
 	return (xmlhttp);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////
-function ClearMessage(StatusMsg_control_name)
-{
-	var StatusMsg_control_name2 = StatusMsg_control_name + "2";
-	document.getElementById(StatusMsg_control_name).innerHTML = "&nbsp;";
-	document.getElementById(StatusMsg_control_name2).innerHTML = "&nbsp;";
-	clearInterval(mTimer);
-}
-
 ////////////////////////////////////////////////////////////////////////////////////
 function AddMenuItem(i)
 {
@@ -453,11 +432,13 @@ function RetrieveMenuItems()
 		return;
 	}
 		
-	if (document.getElementById("StatusMsg").innerHTML == " ")
-	{
-		document.getElementById("StatusMsg").innerHTML = "Retrieving menu items...";
-		document.getElementById("StatusMsg2").innerHTML = "Retrieving menu items...";
-	}
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = "Retrieving menu items...";
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+	
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -465,7 +446,7 @@ function RetrieveMenuItems()
 	{
 		xmlhttp.open("POST","populate_menu_items.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp, "StatusMsg", "Populate");
+		xmlhttp = UpdateMessage(xmlhttp, "Populate");
 		params = "menu=" + document.getElementById("selectMenu").value;
 		xmlhttp.send(params);
 	}
@@ -619,23 +600,17 @@ function RetunToMainConfirm()
 {
 	if (!saved)
 	{
-		var ntop;
-		ntop = tempY;
-		if (ntop < 500)
-			ntop = ntop + 20;
-		else
-			ntop = ntop - 20;
-		var strtop = ntop + "px";
-		
-		document.getElementById("return_confirm").style.display = "block";
-		document.getElementById("return_confirm").style.position = "absolute";
-		document.getElementById("return_confirm").style.top = strtop;
-		document.getElementById("return_confirm").style.left = "200px";
-		document.getElementById("return_confirm").style.width = "450px";
-		document.getElementById("return_confirm").style.backgroundColor = "#FFF";
-		document.getElementById("return_confirm").style.borderStyle = "solid";
-		document.getElementById("return_confirm").style.borderWidth = "2px";
-		document.getElementById("return_confirm").style.borderColor = "#000";
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 300;
+		popup_msg.popup_msg_type = 3;
+		popup_msg.popup_btn_cnt = 2;
+		popup_msg.popup_msg_cell = "Your changes have not been saved. Do you want to save your changes before returning to the main menu?";
+		popup_msg.popup_button_2_span = "Yes";
+		popup_msg.popup_button_1_span = "No";
+		popup_msg.popup_timeout = -1;
+		popup_msg.ShowPopupMsg();
+		document.getElementById("popup_button_2_span").onclick = function () { ReturnToMainMenu(1); };
+		document.getElementById("popup_button_1_span").onclick = function () { ReturnToMainMenu(0); };
 	}
 	else
 		window.location.href = "main.php?mode=edit";
@@ -644,7 +619,15 @@ function RetunToMainConfirm()
 function ReturnToMainMenu(response)
 {
 	if (response == 1)
+	{
 		UpdateAll();
+		var mTimer2 = setTimeout("GoToMainMenu();", 5000);
+	}
+	else
+		window.location.href = "main.php?mode=edit";
+}
+
+function GoToMainMenu()	{
 	window.location.href = "main.php?mode=edit";
 }
 
