@@ -63,6 +63,8 @@
 // Added modal display of buttons for plugins.
 // Revised: 3/10/2013	ELL
 // Re-arranged buttons and added group boxes to change layout from access-level oriented to function oriented.
+// Revised: 4/9/2013	ELL
+// Added plugin installation.
 	
 	include ("check_session.php");
 	
@@ -215,7 +217,6 @@ function ChangeViewMode(mode)
 	
 		document.getElementById("blog_select").style.display="none";
 		document.getElementById("create_page").style.display="none";
-		document.getElementById("edit_menu_items_schedule").style.display="none";
 		document.getElementById("page_titles").style.display="none";
 		document.getElementById("delete_restore_page").style.display="none";
 		document.getElementById("copy_rename_page").style.display="none";
@@ -436,15 +437,7 @@ function ChangeViewMode(mode)
 		}
 		else
 			document.getElementById("create_page").style.display="none";
-		if (mode == "schedule")
-		{
-			document.getElementById("edit_menu_items_schedule").style.position="absolute";
-			document.getElementById("edit_menu_items_schedule").style.left="370px";
-			document.getElementById("edit_menu_items_schedule").style.top="50px";
-			document.getElementById("edit_menu_items_schedule").style.display=inherit;
-		}
-		else
-			document.getElementById("edit_menu_items_schedule").style.display="none";
+		
 		if (mode == "title")
 		{
 			document.getElementById("page_titles").style.position="absolute";
@@ -872,12 +865,6 @@ function HideActivateDeactivate()
      </td></tr></table>
 </div>
 
-	<div id="edit_menu_items_schedule">
-		<p><a href='edit_schedule.php' title='Revise Schedule'>Revise Schedule</a>
-</p>
-	<p><a href='edit_menu_items.php' title='Edit Menu Items'>Edit Menu Items</a></p>
-</div>
-    
     <div id="page_titles">
   <table border="0" width="100%">
 		<tr>
@@ -1163,6 +1150,8 @@ function HideActivateDeactivate()
   <hr/>
   <p><a href='prune_bkup_files.php' title='Prune CSS, site map, and menu JS backup files'>Prune CSS, site map, and JavaScript menu backup files</a></p>
   <hr />
+  <p><a href='upload_plugin.php' title='Install Plugin'>Install Plugin</a></p>
+  <hr/>
   Select the plugin you want to recall:<br />
   	<select name="recall_plugin" id="recall_plugin" style="width:400px;">
 <?php
@@ -1259,7 +1248,8 @@ function HideActivateDeactivate()
 </div>
 
 <script language="JavaScript"  type="text/javascript">
-if ((browser == "Opera") || (browser == "Explorer"))
+//alert(browser + " " + browser_version);
+if ((browser == "Opera") || ((browser == "Explorer") && (browser_version < "10")))
 {
 	document.getElementById("content_label").style.top = "-25px";
 	document.getElementById("menu_label").style.top = "-25px";
@@ -1267,6 +1257,14 @@ if ((browser == "Opera") || (browser == "Explorer"))
 	document.getElementById("page_label").style.top = "-25px";
 	document.getElementById("other_label").style.top = "-25px";
 }
+if ((browser == "Explorer") && (browser_version < "7"))
+{
+	document.getElementById("content_label").style.top = "0px";
+	document.getElementById("menu_label").style.top = "0x";
+	document.getElementById("style_label").style.top = "0px";
+	document.getElementById("page_label").style.top = "0px";
+	document.getElementById("other_label").style.top = "0px";
+}
 </script>
 </body>
 </html>
