@@ -5,9 +5,37 @@
 // For licensing, see license.txt.
 // Created: 6/4/2009
 // Added table prefix handling.  Added references to website files folder configurations.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
 	
 	include ("check_session.php");
 	
+	// Get last used indexes to preload add-new forms.
+	function GetNextIndex($table_prefix, $dbh)
+	{
+		$query = "SELECT head_name FROM " . $table_prefix . "head ORDER BY head_name DESC";
+		$result = $dbh->query($query);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$head_name = $row["head_name"];
+		
+		$index = array();
+		$i = 1;
+		$index[0] = substr($head_name, strlen('head'));
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
+		{
+			$head_name = $row["head_name"];
+			$index[$i] = substr($head_name, strlen('head'));
+			$i++;
+		}
+		sort($index);
+		$index[$i-1] = $index[$i-1] + 1;
+		$next_index = $index[$i-1];
+			
+		return $next_index;
+	}
+	
+	$next_head = GetNextIndex(BWB_TABLE_PREFIX, $bwb_dbh);
+	
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
@@ -18,39 +46,9 @@
 <link rel="stylesheet" href="manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
-<script language="javascript" type="text/javascript">
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_head", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-
-function DeleteConfirm()
-{
-	document.getElementById("delete_confirm").style.display = "block";
-	document.getElementById("delete_confirm").style.position = "absolute";
-	document.getElementById("delete_confirm").style.top = "200px";
-	document.getElementById("delete_confirm").style.left = "300px";
-	document.getElementById("delete_confirm").style.width = "450px";
-	document.getElementById("delete_confirm").style.backgroundColor = "#FFF";
-	document.getElementById("delete_confirm").style.borderStyle = "solid";
-	document.getElementById("delete_confirm").style.borderWidth = "2px";
-	document.getElementById("delete_confirm").style.borderColor = "#000";
-	document.getElementById("delete_text").innerHTML = document.getElementById("head_name").value;
-}
-
-function DeleteHead()
-{
-	var head_name = document.getElementById("head_name").value;
-	document.getElementById("delete_confirm").style.display = "none";
-	var url = "delete_head.php?head_name=" + head_name;
-	window.location = url;
-}
-
-function HideDelete()
-{
-	document.getElementById("delete_confirm").style.display = "none";
-}
-</script>
+<script type="text/javascript" src="js/mouse_position.js"></script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
+<script type="text/javascript" src="js/manage_head.js"></script>
 
 </head>
 
@@ -62,6 +60,8 @@ function HideDelete()
 <tr>
 <td align="center">
   <form name="frmAddHead" method="post" action="add_head.php">
+  head<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_head; ?>" />
+<br />
   <input type="submit" name="submit" value="Add Another Head Content" />
   </form>
 </td>
@@ -146,9 +146,53 @@ function HideDelete()
 <br />
 
 	<table width="80%" border="1" align="center"><tr><td>
-    <span class="sub_title">Delete Head Content</span>
-	<table width="100%" align="center" border="0"><tr>
-	  <td align="center">Select the head content you want to delete: </td>
+    
+	<table width="100%" align="center" border="0">
+      <tr>
+      	<td class="sub_title">Rename Head Content</td>
+      	<td class="sub_title">Delete Head Content</td>
+      </tr>
+      <tr>
+        <td>
+          <form name="frmRename" method="post" action="rename_head.php">
+      	  <table width="100%" align="center" border="0">
+      		<tr>
+              <td align="right">Select head content to rename: </td>
+              <td>
+                <select name="head_old_name" id="head_old_name">
+            <?php
+                $query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head ORDER BY head_name";
+                $result = $bwb_dbh->query($query);
+                while($row = $result->fetch(PDO::FETCH_ASSOC))
+                {
+                    $head_name = $row["head_name"];
+                    if ($head_name != "head")
+					{
+                        echo "<option value='$head_name'>$head_name</option>\n";
+					}
+                }
+            ?>
+                </select>
+              </td>
+              <td align="right">New name: </td>
+              <td align="right" style="width:60px;">
+              <div id="name_prefix_display">head_</div>
+              <input type="hidden" name="name_prefix" id="name_prefix" value="head_" />
+              </td>
+              <td><input type="text" name="name_suffix" id="name_suffix" style="width:100px;" /></td>
+              <td align="center">
+              <input type="submit" name="Submit" value="Rename" />
+              </td>
+			</tr>
+         </table>
+         </form>
+      </td>
+      
+      <td>
+      <table>
+      <tr>
+      
+	  <td align="center">Select  head content  to delete: </td>
 	  <td>
 		<select name="head_name" id="head_name">
 	<?php
@@ -166,7 +210,13 @@ function HideDelete()
 	  <td align="center">
 	  <input type="button" name="delete" value="Delete" onclick="DeleteConfirm();">
 	  </td>
+      
+      </tr>
+      </table>
+     </td>
+     
 	</tr></table>
+    
     </td></tr></table>
 
 <br />
@@ -183,18 +233,10 @@ function HideDelete()
   </tr>
 </table>
 
-<div id="delete_confirm">
-<table border="0" cellspacing="0" cellpadding="5" align="center">
-  <tr>
-    <td colspan="2">Are your sure you want to delete the <b><div id="delete_text">&nbsp;</div></b> menu?</td>
-  </tr>
-  <tr>
-	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeleteHead();" /></td>
-	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();" />
-    </td>
-  </tr>
-</table>
-</div>
+<?php include("lib/popup_msg.html"); ?>
 
+<script language="javascript" type="text/javascript">
+	HidePopupMsg();
+</script>
 </body>
 </html>
\ No newline at end of file
