@@ -13,6 +13,8 @@
 // Fixed bug of adding JavaScript menu code to header even though CSS menu type upon assigning menus.
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
 //
 	
 	include ("check_session.php");
@@ -33,6 +35,10 @@
 }
 </style>
 
+<script type="text/javascript" src="js/mouse_position.js"></script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
+<script type="text/javascript" src="js/manage_menu.js"></script>
+
 <script language="javascript" type="text/javascript" >
 function UpdateDescription(menu_name)
 {
@@ -111,59 +117,6 @@ function UpdateType(menu_name)
 		}
 	}
 }
-function SubmitUpdateType()
-{
-	alert("You will need to re-assign this menu to the border area to complete the conversion.");
-	document.forms["frmUpdateMenuType"].submit();
-}
-
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_menu", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-
-function DeleteConfirm()
-{
-	document.getElementById("delete_confirm").style.display = "block";
-	document.getElementById("delete_confirm").style.position = "absolute";
-	document.getElementById("delete_confirm").style.top = "200px";
-	document.getElementById("delete_confirm").style.left = "300px";
-	document.getElementById("delete_confirm").style.width = "450px";
-	document.getElementById("delete_confirm").style.backgroundColor = "#FFF";
-	document.getElementById("delete_confirm").style.borderStyle = "solid";
-	document.getElementById("delete_confirm").style.borderWidth = "2px";
-	document.getElementById("delete_confirm").style.borderColor = "#000";
-	document.getElementById("delete_text").innerHTML = document.getElementById("selectMenuDelete").value;
-}
-
-function DeleteMenu()
-{
-	var menu = document.getElementById("selectMenuDelete").value;
-	document.getElementById("delete_confirm").style.display = "none";
-	var url = "delete_menu.php?menu=" + menu;
-	window.location = url;
-}
-
-function HideDelete()
-{
-	document.getElementById("delete_confirm").style.display = "none";
-}
-
-function UpdateMenuType(nFrmIndex)
-{
-	var sFormName = "frmAssign" + nFrmIndex;
-	var frmElement = document.forms[sFormName]
-	var cntMenuSelect = frmElement.elements["menu_name"];
-	var cntMenuType = frmElement.elements["menu_type"];
-	var nSelectedIndex = cntMenuSelect.selectedIndex;
-	var sMenuSting = cntMenuSelect.options[nSelectedIndex].text;
-	// menu_type = 1 ---> JavaScript, menu_type = 0 ---> CSS
-	var nResult = sMenuSting.indexOf("(JavaScript)");
-	if (nResult > 0)
-		cntMenuType.value = 1;
-	else
-		cntMenuType.value = 0;
-}
 </script>
 
 </head>
@@ -375,18 +328,10 @@ Menu Type:
 &nbsp;
 </div>
 
-<div id="delete_confirm">
-<table border="0" cellspacing="0" cellpadding="5" align="center">
-  <tr>
-    <td colspan="2">Are your sure you want to delete the <b><div id="delete_text">&nbsp;</div></b> menu?</td>
-  </tr>
-  <tr>
-	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeleteMenu();" /></td>
-	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();" />
-    </td>
-  </tr>
-</table>
-</div>
+<?php include("lib/popup_msg.html"); ?>
 
+<script language="javascript" type="text/javascript">
+	HidePopupMsg();
+</script>
 </body>
 </html>
\ No newline at end of file
