@@ -8,8 +8,78 @@
 // Fixed bug of assignments corrupting templates that do not have all 4: top, bottom, left and right sections.
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.  Added references to website files folder configurations.
+// Revised: 5/10/2013	ELL
+// Added new areas header and footer.  Headers go above the top cell and footers go below the bottom cell.
+// Revised: 6/24/2013	ELL
+// Added ability to specify meaningful names.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
+
 	
 	include ("check_session.php");
+	
+	// Get last used indexes to preload add-new forms.
+	function GetNextIndex($area_type, $table_prefix, $dbh)
+	{
+		$query = "SELECT page_name FROM " . $table_prefix . "page_data_special WHERE page_name LIKE '". $area_type . "%' ORDER BY page_name DESC";
+		$result = $dbh->query($query);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$page_name = $row["page_name"];
+		
+		$index = array();
+		$i = 1;
+		$index[0] = substr($page_name, strlen($area_type));
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
+		{
+			$page_name = $row["page_name"];
+			$index[$i] = substr($page_name, strlen($area_type));
+			$i++;
+		}
+		sort($index);
+		$index[$i-1] = $index[$i-1] + 1;
+		$next_index = $index[$i-1];
+			
+		return $next_index;
+	}
+	
+	function GetAreaFromName($page_name)
+	{
+		switch (substr($page_name, 0, 1))	{
+		case 't':
+			$initial_prefix = "top_";
+			break;
+		case 'b':
+			$initial_prefix = "bottom_";
+			break;
+		case 'l':
+			$initial_prefix = "left_";
+			break;
+		case 'r':
+			$initial_prefix = "right_";
+			break;
+		case 'h':
+			$initial_prefix = "header_";
+			break;
+		case 'f':
+			$initial_prefix = "footer_";
+			break;
+		}
+		
+		return($initial_prefix);
+	}
+	
+	$area_type = "right";
+	$next_right = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
+	$area_type = "left";
+	$next_left = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
+	$area_type = "top";
+	$next_top = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
+	$area_type = "bottom";
+	$next_bottom = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
+	$area_type = "header";
+	$next_header = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
+	$area_type = "footer";
+	$next_footer = GetNextIndex($area_type, BWB_TABLE_PREFIX, $bwb_dbh);
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
@@ -28,48 +98,8 @@
 </style>
 
 <script type="text/javascript" src="js/mouse_position.js"></script>
-
-<script language="javascript" type="text/javascript">
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_special", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-
-function DeleteConfirm()
-{
-	var ntop;
-	ntop = tempY;
-	if (ntop < 500)
-		ntop = ntop + 20;
-	else
-		ntop = ntop - 20;
-	var strtop = ntop + "px";
-	
-	document.getElementById("delete_confirm").style.display = "block";
-	document.getElementById("delete_confirm").style.position = "absolute";
-	document.getElementById("delete_confirm").style.top = strtop;
-	document.getElementById("delete_confirm").style.left = "200px";
-	document.getElementById("delete_confirm").style.width = "450px";
-	document.getElementById("delete_confirm").style.backgroundColor = "#FFF";
-	document.getElementById("delete_confirm").style.borderStyle = "solid";
-	document.getElementById("delete_confirm").style.borderWidth = "2px";
-	document.getElementById("delete_confirm").style.borderColor = "#000";
-	document.getElementById("delete_text").innerHTML = document.getElementById("area_name").value;
-}
-
-function DeletePage()
-{
-	var area_name = document.getElementById("area_name").value;
-	document.getElementById("delete_confirm").style.display = "none";
-	var url = "delete_special.php?area_name=" + area_name;
-	window.location = url;
-}
-
-function HideDelete()
-{
-	document.getElementById("delete_confirm").style.display = "none";
-}
-</script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
+<script type="text/javascript" src="js/manage_special.js"></script>
 
 </head>
 
@@ -84,28 +114,53 @@ function HideDelete()
 <tr>
 <td align="center">
 <form name="frmAddRight" method="post" action="add_special.php">
+right<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_right; ?>" />
+<br />
 <input type="submit" name="submit" value="Add Another Right Area" />
 <input type="hidden" name="area_type" value="right" />
 </form>
 </td>
 <td align="center">
 <form name="frmAddLeft" method="post" action="add_special.php">
+left<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_left; ?>"/>
+<br />
 <input type="submit" name="submit" value="Add Another Left Area" />
 <input type="hidden" name="area_type" value="left" />
 </form>
 </td>
 <td align="center">
 <form name="frmTop" method="post" action="add_special.php">
+top<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_top; ?>"/>
+<br />
 <input type="submit" name="submit" value="Add Another Top Area" />
 <input type="hidden" name="area_type" value="top" />
 </form>
 </td>
 <td align="center">
 <form name="frmBottom" method="post" action="add_special.php">
+bottom<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_bottom; ?>" />
+<br />
 <input type="submit" name="submit" value="Add Another Bottom Area" />
 <input type="hidden" name="area_type" value="bottom" />
 </form>
 </td>
+<td align="center">
+<form name="frmHeader" method="post" action="add_special.php">
+header<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_header; ?>" />
+<br />
+<input type="submit" name="submit" value="Add Another Header Area" />
+<input type="hidden" name="area_type" value="header" />
+</form>
+</td>
+<td align="center">
+<form name="frmFooter" method="post" action="add_special.php">
+footer<input type="text" name="suffix" style="width:100px;" value="<?php echo $next_footer; ?>" />
+<br />
+<input type="submit" name="submit" value="Add Another Footer Area" />
+<input type="hidden" name="area_type" value="footer" />
+</form>
+</td>
+
 </tr>
 </table>
 </td></tr></table>
@@ -113,10 +168,10 @@ function HideDelete()
 
 <table width="80%" border="1" align="center"><tr><td>
 <table width="100%" border="0" align="center">
-<tr bgcolor="#CCCCCC"><td colspan="6"><span class="sub_title">Assign Special Area to Page</span></td></tr>
+<tr bgcolor="#CCCCCC"><td colspan="8"><span class="sub_title">Assign Special Area to Page</span></td></tr>
   <?php
   		$bgcolor = "#EEEEEE";
-		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data";
+		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
 		$result = $bwb_dbh->query($query);
 		$i = 1;
 		while($row = $result->fetch(PDO::FETCH_ASSOC))
@@ -149,6 +204,8 @@ function HideDelete()
 			$search_str_left = "page_name='left";
 			$search_str_top = "page_name='top";
 			$search_str_bottom = "page_name='bottom";
+			$search_str_header = "page_name='header";
+			$search_str_footer = "page_name='footer";
 		
 			$start_pos = strpos($contents, $search_str_right, 1);
 			if ($start_pos !== false)
@@ -189,13 +246,33 @@ function HideDelete()
 			}
 			else
 				$bottom_str = "-na-";
+				
+			$start_pos = strpos($contents, $search_str_header, 1);
+			if ($start_pos !== false)
+			{
+				$end_pos = strpos($contents, "\"", $start_pos) - 1;
+				$start_pos = $start_pos + strlen("page_name='");
+				$header_str = substr($contents, $start_pos, $end_pos - $start_pos);
+			}
+			else
+				$header_str = "-na-";
+				
+			$start_pos = strpos($contents, $search_str_footer, 1);
+			if ($start_pos !== false)
+			{
+				$end_pos = strpos($contents, "\"", $start_pos) - 1;
+				$start_pos = $start_pos + strlen("page_name='");
+				$footer_str = substr($contents, $start_pos, $end_pos - $start_pos);
+			}
+			else
+				$footer_str = "-na-";
 			////////////////////////////////////
 			
 			echo "<td>\n";
 			if ($right_str != "-na-")
 			{
 				echo "<select name=\"right_area_name\">\n";
-				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
 				$result2 = $bwb_dbh->query($query2);
 				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 				{
@@ -215,7 +292,7 @@ function HideDelete()
 			if ($left_str != "-na-")
 			{
 				echo "<select name=\"left_area_name\">\n";
-				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
 				$result2 = $bwb_dbh->query($query2);
 				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 				{
@@ -235,7 +312,7 @@ function HideDelete()
 			if ($top_str != "-na-")
 			{
 				echo "<select name=\"top_area_name\">\n";
-				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
 				$result2 = $bwb_dbh->query($query2);
 				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 				{
@@ -255,7 +332,7 @@ function HideDelete()
 			if ($bottom_str != "-na-")
 			{
 				echo "<select name=\"bottom_area_name\">\n";
-				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
 				$result2 = $bwb_dbh->query($query2);
 				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 				{
@@ -271,6 +348,46 @@ function HideDelete()
 			echo "</select>\n";
 			echo "</td>\n";
 			
+			echo "<td>\n";
+			if ($header_str != "-na-")
+			{
+				echo "<select name=\"header_area_name\">\n";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
+				$result2 = $bwb_dbh->query($query2);
+				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
+				{
+					$area_name = $row2["page_name"];
+					if ($area_name == $header_str)
+						echo "<option value='$area_name' selected='selected'>$area_name</option>\n";
+					elseif(substr($area_name,0,3) == "hea")
+						echo "<option value='$area_name'>$area_name</option>\n";
+				}
+						}
+			else
+				echo "-na-";
+			echo "</select>\n";
+			echo "</td>\n";
+			
+			echo "<td>\n";
+			if ($footer_str != "-na-")
+			{
+				echo "<select name=\"footer_area_name\">\n";
+				$query2 = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
+				$result2 = $bwb_dbh->query($query2);
+				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
+				{
+					$area_name = $row2["page_name"];
+					if ($area_name == $footer_str)
+						echo "<option value='$area_name' selected='selected'>$area_name</option>\n";
+					elseif(substr($area_name,0,3) == "foo")
+						echo "<option value='$area_name'>$area_name</option>\n";
+				}
+						}
+			else
+				echo "-na-";
+			echo "</select>\n";
+			echo "</td>\n";
+			
 			echo "<td>\n";
 			echo "<input type='submit' name='submit' value='Assign' />\n";
 			echo "<input type='hidden' name='page_name' value='$page_name' />\n";
@@ -288,27 +405,81 @@ function HideDelete()
 </td></tr></table>
 <br />
 	<table width="80%" border="1" align="center"><tr><td>
-    <span class="sub_title">Delete Special Area</span>
-	<table width="100%" align="center" border="0"><tr>
-	  <td align="center">Select the border area you want to delete: </td>
-	  <td>
-		<select name="area_name" id="area_name">
-	<?php
-		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special";
-		$result = $bwb_dbh->query($query);
-		while($row = $result->fetch(PDO::FETCH_ASSOC))
-		{
-			$page_name = $row["page_name"];
-			if (($page_name != "top") && ($page_name != "bottom") && ($page_name != "left") && ($page_name != "right"))
-				echo "<option value='$page_name'>$page_name</option>";
-		}
-	?>
-		</select>
-	  </td>
-	  <td align="center">
-	  <input type="button" name="Submit" value="Delete" onclick="DeleteConfirm();">
-	  </td>
-	</tr></table>
+    
+	<table width="100%" align="center" border="0">
+      <tr>
+        <td>
+        	<span class="sub_title">Rename Special Area</span>
+        </td>
+        <td>
+            <span class="sub_title">Delete Special Area</span>
+        </td>
+      </tr>
+      <tr>
+      	<td>
+          <form name="frmRename" method="post" action="rename_special.php">
+      	  <table width="100%" align="center" border="0">
+      		<tr>
+              <td align="right">Select  border area  to rename: </td>
+              <td>
+                <select name="area_old_name" id="area_old_name" onchange="var prefix=GetAreaFromName(this.value); document.getElementById('name_prefix_display').innerHTML=prefix; document.getElementById('name_prefix').value=prefix;">
+            <?php
+                $query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
+                $result = $bwb_dbh->query($query);
+                while($row = $result->fetch(PDO::FETCH_ASSOC))
+                {
+                    $page_name = $row["page_name"];
+                    if (($page_name != "top") && ($page_name != "bottom") && ($page_name != "left") && ($page_name != "right") && ($page_name != "header") && ($page_name != "footer"))
+					{
+                        echo "<option value='$page_name'>$page_name</option>\n";
+						if (!isset($initial_prefix))
+							$initial_prefix = GetAreaFromName($page_name);
+					}
+                }
+            ?>
+                </select>
+              </td>
+              <td align="right">New name: </td>
+              <td align="right" style="width:60px;">
+              <div id="name_prefix_display"><?php echo $initial_prefix; ?></div>
+              <input type="hidden" name="name_prefix" id="name_prefix" value="<?php echo $initial_prefix; ?>" />
+              </td>
+              <td><input type="text" name="name_suffix" id="name_suffix" style="width:100px;" /></td>
+              <td align="center">
+              <input type="submit" name="Submit" value="Rename" />
+              </td>
+			</tr>
+         </table>
+         </form>
+      </td>
+      <td>
+        <table width="100%" align="center" border="0">
+      		<tr>
+              <td align="right">Select  border area  to delete: </td>
+              <td>
+                <select name="area_name" id="area_name">
+            <?php
+                $query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
+                $result = $bwb_dbh->query($query);
+                while($row = $result->fetch(PDO::FETCH_ASSOC))
+                {
+                    $page_name = $row["page_name"];
+                    if (($page_name != "top") && ($page_name != "bottom") && ($page_name != "left") && ($page_name != "right") && ($page_name != "header") && ($page_name != "footer"))
+                        echo "<option value='$page_name'>$page_name</option>\n";
+                }
+            ?>
+                </select>
+              </td>
+              <td align="center">
+              <input type="button" name="Submit" value="Delete" onclick="DeleteConfirm();">
+              </td>
+            </tr>
+        </table>
+    
+       </td>
+     </tr>
+    </table>
+    
     </td></tr></table>
 
 <br />
@@ -318,18 +489,12 @@ function HideDelete()
   </td></tr>
 </table>
 
-<div id="delete_confirm">
-<table border="0" cellspacing="0" cellpadding="5" align="center">
-  <tr>
-    <td colspan="2">Are your sure you want to delete the <b><div id="delete_text">&nbsp;</div></b> page?</td>
-  </tr>
-  <tr>
-	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeletePage();" /></td>
-	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();" />
-    </td>
-  </tr>
-</table>
-</div>
+<?php include("lib/popup_msg.html"); ?>
+
+<script language="javascript" type="text/javascript">
+	HidePopupMsg();
+</script>
+
 
 </body>
 </html>
\ No newline at end of file
