@@ -14,6 +14,10 @@
 // Added selection for having sub menus collapse and expand.  Default is to collapse and expand.  New option is to show always expanded.
 // Revised: 2/10/2012	ELL
 // Added table prefix handling.  Added references to CSS folder configurations.
+// Revised: 6/19/2013	ELL
+// Added separate text alignment for sub menus.
+// Revised: 7/21/2013	ELL
+// Fixed bug with opacity being left at 0 if menu freshly cerated.
 // 
 //
 //
@@ -45,8 +49,8 @@
 	else $top_level_item_height = -1;
 	if (is_numeric($_POST["top_level_item_height_units"])) $top_level_item_height_units = $_POST["top_level_item_height_units"];
 	else $top_level_item_height_units = 0;
-	if (isset($_POST["text_align"])) $text_align = $_POST["text_align"];
-	else $position = "-not selected-";
+	if (isset($_POST["top_level_text_align"])) $top_level_text_align = $_POST["top_level_text_align"];
+	else $top_level_text_align = "-not selected-";
 	if (is_numeric($_POST["top_level_padding_top"])) $top_level_padding_top = $_POST["top_level_padding_top"];
 	else $top_level_padding_top = 2;
 	if (is_numeric($_POST["top_level_padding_right"])) $top_level_padding_right = $_POST["top_level_padding_right"];
@@ -75,6 +79,8 @@
 	else $sub_level_padding_bottom = 2;
 	if (is_numeric($_POST["sub_level_padding_left"])) $sub_level_padding_left = $_POST["sub_level_padding_left"];
 	else $sub_level_padding_left = 10;
+	if (isset($_POST["sub_level_text_align"])) $sub_level_text_align = $_POST["sub_level_text_align"];
+	else $sub_level_text_align = "-not selected-";
 	if (isset($_POST["proportional_width_top"])) $proportional_width_top = $_POST["proportional_width_top"];
 	else $proportional_width_top = 0;
 	if (isset($_POST["proportional_width_sub"])) $proportional_width_sub = $_POST["proportional_width_sub"];
@@ -92,11 +98,11 @@
 		if ($orientation == "vertical")
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=0, padding_right=0, padding_bottom=0,"
 			. " padding_left=0, margin_top=0, margin_right=0, margin_left=0, margin_bottom=0, display='-not selected-',"
-			. " list_style_type='none' WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
+			. " list_style_type='none', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
 		else
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=0, padding_right=0, padding_bottom=0,"
-			. " padding_lef=0, margin_top=0, margin_right=0, margin_left=0, margin_bottom=0, display='inline', "
-			. "list_style_type='none' WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
+			. " padding_left=0, margin_top=0, margin_right=0, margin_left=0, margin_bottom=0, display='inline', "
+			. "list_style_type='none', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
 	}
 	else
 	{
@@ -104,11 +110,11 @@
 		if ($orientation == "vertical")
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul', use_table_data=1, padding_top=0,"
 			. " padding_right=0, padding_bottom=0, padding_left=0, margin_top=0, margin_right=0, margin_left=0, margin_bottom=0,"
-			. " display='-not selected-', list_style_type='none', border=-2";
+			. " display='-not selected-', list_style_type='none', border=-2, bkgd_opacity=-1";
 		else
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul', use_table_data=1, padding_top=0,"
 			. " padding_right=0, padding_bottom=0, padding_left=0, margin_top=0, margin_right=0, margin_left=0, margin_bottom=0,"
-			. " display='inline', list_style_type='none', border=-2";
+			. " display='inline', list_style_type='none', border=-2, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -121,19 +127,19 @@
 		//Update class record.
 		if ($orientation == "horizontal_variable_width")
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='table', width=". $menu_width . ", width_units="
-			. $menu_width_units . ", table_layout='fixed', align='" . $text_align . "' WHERE class='ul.nav" . $suffix . "'";
+			. $menu_width_units . ", table_layout='fixed', align='" . $top_level_text_align . "', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . "'";
 		else
-			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='table', width=-1, table_layout='-not selected-', align='" . $text_align . "'"
-			. " WHERE class='ul.nav" . $suffix . "'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='table', width=-1, table_layout='-not selected-', align='" . $top_level_text_align . "'"
+			. ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . "'";
 	}
 	else
 	{
 		//Insert new data into table.
 		if ($orientation == "horizontal_variable_width")
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . "', use_table_data=1, display='table', width=" 
-			. $menu_width . ", width_units=" . $menu_width_units . ", align='" . $text_align . "', table_layout='fixed'";
+			. $menu_width . ", width_units=" . $menu_width_units . ", align='" . $top_level_text_align . "', table_layout='fixed', bkgd_opacity=-1";
 		else
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . "', use_table_data=1, display='table', width=-1, table_layout='-not selected-', align='" . $text_align . "'";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . "', use_table_data=1, display='table', width=-1, table_layout='-not selected-', align='" . $top_level_text_align . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -150,14 +156,14 @@
 			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
-			. ", position='relative', display='-not selected-' WHERE class='ul.nav" . $suffix . ">li'";
+			. ", position='relative', display='-not selected-', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ">li'";
 		else
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $top_level_padding_top 
 			. ", padding_right=" . $top_level_padding_right
 			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
-			. ", position='relative', display='table-cell' WHERE class='ul.nav" . $suffix . ">li'";
+			. ", position='relative', display='table-cell', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ">li'";
 	}
 	else
 	{
@@ -168,14 +174,14 @@
 			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
-			. ", position='relative', display='-not selected-', z_index=5";
+			. ", position='relative', display='-not selected-', z_index=5, bkgd_opacity=-1";
 		else
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ">li', use_table_data=1, padding_top=" 
 			. $top_level_padding_top . ", padding_right=" . $top_level_padding_right
 			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
-			. ", position='relative', display='table-cell', z_index=5";
+			. ", position='relative', display='table-cell', z_index=5, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -193,14 +199,14 @@
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, margin_top=" . $sub_level_offset_top . ", margin_left=" . $sub_level_offset_left
 		. ", " . $position_display_str . ", width=" . $sub_level_item_width . ", width_units=" . $sub_level_item_width_units
-		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units . " WHERE class='ul.nav" . $suffix . " li>ul'";
+		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units . ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li>ul'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li>ul', use_table_data=1, margin_top=" . $sub_level_offset_top . ", margin_left=" . $sub_level_offset_left
 		. ", " . $position_display_str . ", width=" . $sub_level_item_width . ", width_units=" . $sub_level_item_width_units
-		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units;
+		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units . ", bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -211,12 +217,12 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='block' WHERE class='ul.nav" . $suffix . " li:hover>ul'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='block', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li:hover>ul'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover>ul', use_table_data=1, display='block'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover>ul', use_table_data=1, display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -229,7 +235,7 @@
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $sub_level_padding_top . ", padding_right="
 		. $sub_level_padding_right . ", padding_bottom=" . $sub_level_padding_bottom . ", padding_left=" . $sub_level_padding_left
-		. ", display='block' WHERE class='.nav" . $suffix . " ul li a'";
+		. ", display='block', bkgd_opacity=-1 WHERE class='.nav" . $suffix . " ul li a'";
 	}
 	else
 	{
@@ -237,7 +243,7 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.nav" . $suffix . " ul li a', use_table_data=1, padding_top=" . $sub_level_padding_top
 		. ", padding_right="
 		. $sub_level_padding_right . ", padding_bottom=" . $sub_level_padding_bottom . ", padding_left=" . $sub_level_padding_left
-		. ", display='block'";
+		. ", display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -250,17 +256,49 @@
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, position='" . $position . "', position_top=" . $menu_top
 		. ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, display='block' WHERE class='.menu_div" . $suffix . "'";
+		. ", position_left_units=0, display='block', bkgd_opacity=-1 WHERE class='.menu_div" . $suffix . "'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.menu_div" . $suffix . "', use_table_data=1, position='" . $position . "',"
 		. " position_top=" . $menu_top . ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, display='block'";
+		. ", position_left_units=0, display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
+	//////////////////////////////////////////////////////////////////////////////////////////
+	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_a" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
+	if ($row_count > 0)
+	{
+		//Update class record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, align='" . $sub_level_text_align . "', bkgd_opacity=-1 WHERE class='.sub_level_1_a" . $suffix . "'";
+	}
+	else
+	{
+		//Insert new data into table.
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_a" . $suffix . "', use_table_data=1, align='" . $sub_level_text_align . "', bkgd_opacity=-1";
+	}
+	$cnt = $bwb_dbh->exec($query);
+	
+	//////////////////////////////////////////////////////////////////////////////////////////
+	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_2_a" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
+	if ($row_count > 0)
+	{
+		//Update class record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, align='" . $sub_level_text_align . "', bkgd_opacity=-1 WHERE class='.sub_level_2_a" . $suffix . "'";
+	}
+	else
+	{
+		//Insert new data into table.
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_a" . $suffix . "', use_table_data=1, align='" . $sub_level_text_align . "', bkgd_opacity=-1";
+	}
+	$cnt = $bwb_dbh->exec($query);
+
 	//////////////////////////////////////////////////////////////////////////////////////////
 	//Update menu list for proportional widths.
 	$query = "UPDATE " . BWB_TABLE_PREFIX . "menus SET proportional=" . $proportional_width_top . ", proportional_sub=" . $proportional_width_sub . " WHERE menu_name='" . $menu . "'";
