@@ -19,6 +19,8 @@
 // Added preview mode.
 // Revised: 2/10/2012	ELL
 // Added table prefix handling.  Added references to CSS folder configurations.
+// Revised: 7/21/2013	ELL
+// Added background opacity.
 //
 	include ("check_session.php");
 	include ("lib/copy_table.php");
@@ -224,6 +226,11 @@
 	if (isset($_POST["sub_level_item_border_right"])) $sub_level_item_border_right = $_POST["sub_level_item_border_right"];
 	else $sub_level_item_border_right = 0;
 	$sub_level_item_border_sides = ($sub_level_item_border_top * 8) | ($sub_level_item_border_bottom * 4) | ($sub_level_item_border_left * 2) | $sub_level_item_border_right;
+	
+	if (isset($_POST["top_level_background_opacity"])) $top_level_background_opacity = $_POST["top_level_background_opacity"];
+	else $top_level_background_opacity = -1;
+	if (isset($_POST["sub_level_background_opacity"])) $sub_level_background_opacity = $_POST["sub_level_background_opacity"];
+	else $sub_level_background_opacity = -1;
 		
 	
 	///////////////////////////////////////////////////////////////////////////////////////////
@@ -243,7 +250,7 @@
 		. ", shadow=" . $top_level_shadow
 		. ", shadow_color='" . $top_level_shadow_color . "', shadow_x_offset=" . $top_level_shadow_x_offset
 		. ", shadow_y_offset=" . $top_level_shadow_y_offset . ", shadow_blur=" . $top_level_shadow_blur
-		. ", text_color='" . $top_level_text_color . "' WHERE class='.top_level_a" . $suffix . "'";
+		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1 WHERE class='.top_level_a" . $suffix . "'";
 	}
 	else
 	{
@@ -255,7 +262,7 @@
 		. ", shadow=" . $top_level_shadow
 		. ", shadow_color='" . $top_level_shadow_color . "', shadow_x_offset=" . $top_level_shadow_x_offset
 		. ", shadow_y_offset=" . $top_level_shadow_y_offset . ", shadow_blur=" . $top_level_shadow_blur
-		. ", text_color='" . $top_level_text_color . "'";
+		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -276,7 +283,7 @@
 		. ", shadow=" . $sub_level_1_shadow
 		. ", shadow_color='" . $sub_level_1_shadow_color . "', shadow_x_offset=" . $sub_level_1_shadow_x_offset
 		. ", shadow_y_offset=" . $sub_level_1_shadow_y_offset . ", shadow_blur=" . $sub_level_1_shadow_blur
-		. ", text_color='" . $sub_level_1_text_color . "' WHERE class='.sub_level_1_a" . $suffix . "'";
+		. ", text_color='" . $sub_level_1_text_color . "', bkgd_opacity=-1 WHERE class='.sub_level_1_a" . $suffix . "'";
 	}
 	else
 	{
@@ -288,7 +295,7 @@
 		. ", shadow=" . $sub_level_1_shadow
 		. ", shadow_color='" . $sub_level_1_shadow_color . "', shadow_x_offset=" . $sub_level_1_shadow_x_offset
 		. ", shadow_y_offset=" . $sub_level_1_shadow_y_offset . ", shadow_blur=" . $sub_level_1_shadow_blur
-		. ", text_color='" . $sub_level_1_text_color . "'";
+		. ", text_color='" . $sub_level_1_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -309,7 +316,7 @@
 		. ", shadow=" . $sub_level_2_shadow
 		. ", shadow_color='" . $sub_level_2_shadow_color . "', shadow_x_offset=" . $sub_level_2_shadow_x_offset
 		. ", shadow_y_offset=" . $sub_level_2_shadow_y_offset . ", shadow_blur=" . $sub_level_2_shadow_blur
-		. ", text_color='" . $sub_level_2_text_color . "' WHERE class='.sub_level_2_a" . $suffix . "'";
+		. ", text_color='" . $sub_level_2_text_color . "', bkgd_opacity=-1 WHERE class='.sub_level_2_a" . $suffix . "'";
 	}
 	else
 	{
@@ -321,7 +328,7 @@
 		. ", shadow=" . $sub_level_2_shadow
 		. ", shadow_color='" . $sub_level_2_shadow_color . "', shadow_x_offset=" . $sub_level_2_shadow_x_offset
 		. ", shadow_y_offset=" . $sub_level_2_shadow_y_offset . ", shadow_blur=" . $sub_level_2_shadow_blur
-		. ", text_color='" . $sub_level_2_text_color . "'";
+		. ", text_color='" . $sub_level_2_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -332,12 +339,12 @@
 	if ($row_count > 0)
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, border=" . $top_level_block_border_width . ", border_color='" . $top_level_block_border_color . "', border_sides=" . $top_level_block_border_sides
-		. " WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
+		. ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul'";
 	}
 	else
 	{
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul', use_table_data=1, border=" . $top_level_block_border_width
-		. ", border_color='" . $top_level_block_border_color . "', border_sides=" . $top_level_block_border_sides;
+		. ", border_color='" . $top_level_block_border_color . "', border_sides=" . $top_level_block_border_sides . ", bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -349,13 +356,13 @@
 	{
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_color='" . $top_level_background_color 
 		. "', border=" . $top_level_item_border_width
-		. ", border_color='" . $top_level_item_border_color . "', border_sides=" . $top_level_item_border_sides . " WHERE class='ul.nav" . $suffix . ">li'";
+		. ", border_color='" . $top_level_item_border_color . "', border_sides=" . $top_level_item_border_sides . ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ">li'";
 	}
 	else
 	{
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ">li', use_table_data=1, bkgd_color='" . $top_level_background_color 
 		. "', border=" . $top_level_item_border_width
-		. ", border_color='" . $top_level_item_border_color . "', border_sides=" . $top_level_item_border_sides . "', z_index=5";
+		. ", border_color='" . $top_level_item_border_color . "', border_sides=" . $top_level_item_border_sides . "', z_index=5, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -367,13 +374,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, border=" . $sub_level_block_border_width . ", border_color='" . $sub_level_block_border_color . "', border_sides=" . $sub_level_block_border_sides
-		. " WHERE class='ul.nav" . $suffix . " li>ul'";
+		. ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li>ul'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li>ul', use_table_data=1, border=" . $sub_level_block_border_width
-		. ", border_color='" . $sub_level_block_border_color . "', border_sides=" . $top_level_block_border_sides;
+		. ", border_color='" . $sub_level_block_border_color . "', border_sides=" . $top_level_block_border_sides . ", bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -385,13 +392,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, border=" . $sub_level_item_border_width . ", border_color='"
-		. $sub_level_item_border_color. "', border_sides=" . $sub_level_item_border_sides . " WHERE class='.nav" . $suffix . " ul li a'";
+		. $sub_level_item_border_color. "', border_sides=" . $sub_level_item_border_sides . ", bkgd_opacity=-1 WHERE class='.nav" . $suffix . " ul li a'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.nav" . $suffix . " ul li a', use_table_data=1, border=" . $sub_level_item_border_width . ", border_color='"
-		. $sub_level_item_border_color . "', border_sides=" . $sub_level_item_border_sides;
+		. $sub_level_item_border_color . "', border_sides=" . $sub_level_item_border_sides . ", bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -408,7 +415,7 @@
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_color='" . $top_level_background_color_hover
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
 		. "', border_sides=" . $top_level_item_border_sides
-		. " WHERE class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover'";
+		. ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover'";
 
 	}
 	else
@@ -420,7 +427,7 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover', use_table_data=1, bkgd_color='" 
 		. $top_level_background_color_hover
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
-		. "', border_sides=" . $top_level_item_border_sides . ", z_index=10";
+		. "', border_sides=" . $top_level_item_border_sides . ", z_index=10, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -434,7 +441,7 @@
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_1_text_color_active . "', bkgd_color='" . $top_level_background_color_active
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_active
 		. "', border_sides=" . $top_level_item_border_sides
-		. " WHERE class='ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active'";
+		. ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active'";
 	}
 	else
 	{
@@ -442,7 +449,7 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:active, .nav" . $suffix . " ul li a:active', use_table_data=1, text_color='"
 		. $sub_level_1_text_color_active . "', bkgd_color='" . $top_level_background_color_active
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_active
-		. "', border_sides=" . $top_level_item_border_sides;
+		. "', border_sides=" . $top_level_item_border_sides . ", bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -454,13 +461,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_color='" . $sub_level_background_color
-		. "' WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a'";
+		. "', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ", .nav" . $suffix . " ul, .nav" . $suffix . " ul li a', use_table_data=1, bkgd_color='"
-		. $sub_level_background_color . "'";
+		. $sub_level_background_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -475,7 +482,7 @@
 //		$query = "UPDATE " . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color_hover
 //		. "' WHERE class='.nav" . $suffix . " a:hover'";
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color_hover
-		. "' WHERE class='.top_level_li" . $suffix . " A:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.top_level_li" . $suffix . " A:hover'";
 	}
 	else
 	{
@@ -483,7 +490,7 @@
 //		$query = "INSERT INTO " . $site_css_table . " SET class='.nav" . $suffix . " a:hover', use_table_data=1, text_color='"
 //		. $top_level_text_color_hover . "'";
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:hover', use_table_data=1, text_color='"
-		. $top_level_text_color_hover . "'";
+		. $top_level_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -495,13 +502,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color_hover
-		. "' WHERE class='.top_level_li" . $suffix . " A:visited:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.top_level_li" . $suffix . " A:visited:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
-		. $top_level_text_color_hover . "'";
+		. $top_level_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -513,12 +520,12 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color
-		. "' WHERE class='.top_level_li" . $suffix . " A:visited'";
+		. "', bkgd_opacity=-1 WHERE class='.top_level_li" . $suffix . " A:visited'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $top_level_text_color . "'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $top_level_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -530,13 +537,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_1_text_color_hover
-		. "' WHERE class='.sub_level_1_li" . $suffix . " A:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_1_li" . $suffix . " A:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:hover', use_table_data=1, text_color='"
-		. $sub_level_1_text_color_hover . "'";
+		. $sub_level_1_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -548,13 +555,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_1_text_color_hover
-		. "' WHERE class='.sub_level_1_li" . $suffix . " A:visited:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_1_li" . $suffix . " A:visited:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
-		. $sub_level_1_text_color_hover . "'";
+		. $sub_level_1_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -566,12 +573,12 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_1_text_color
-		. "' WHERE class='.sub_level_1_li" . $suffix . " A:visited'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_1_li" . $suffix . " A:visited'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_1_text_color . "'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_1_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -583,13 +590,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_2_text_color_hover
-		. "' WHERE class='.sub_level_2_li" . $suffix . " A:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_2_li" . $suffix . " A:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:hover', use_table_data=1, text_color='"
-		. $sub_level_2_text_color_hover . "'";
+		. $sub_level_2_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -601,13 +608,13 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_2_text_color_hover
-		. "' WHERE class='.sub_level_2_li" . $suffix . " A:visited:hover'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_2_li" . $suffix . " A:visited:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:visited:hover', use_table_data=1, text_color='"
-		. $sub_level_2_text_color_hover . "'";
+		. $sub_level_2_text_color_hover . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -619,12 +626,12 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_2_text_color
-		. "' WHERE class='.sub_level_2_li" . $suffix . " A:visited'";
+		. "', bkgd_opacity=-1 WHERE class='.sub_level_2_li" . $suffix . " A:visited'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_2_text_color . "'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_li" . $suffix . " A:visited', use_table_data=1, text_color='" . $sub_level_2_text_color . "', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -635,14 +642,47 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='block' WHERE class='.top_level_li" . $suffix . " A'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='block', bkgd_opacity=-1 WHERE class='.top_level_li" . $suffix . " A'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A', use_table_data=1, display='block'";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A', use_table_data=1, display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
+	
+	//////////////////////////////////////////////////////////////////////////////////////////
+	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_ul" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
+	if ($row_count > 0)
+	{
+		//Update class record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_opacity=" . $top_level_background_opacity . " WHERE class='.top_level_ul" . $suffix . "'";
+	}
+	else
+	{
+		//Insert new data into table.
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_ul" . $suffix . "', use_table_data=1, bkgd_opacity=" . $top_level_background_opacity;
+	}
+	$cnt = $bwb_dbh->exec($query);
+	
+	//////////////////////////////////////////////////////////////////////////////////////////
+	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_ul" . $suffix . "'";
+	$result = $bwb_dbh->query($query);
+	$row_count = $result->rowCount();
+	if ($row_count > 0)
+	{
+		//Update class record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_opacity=" . $sub_level_background_opacity . " WHERE class='.sub_level_1_ul" . $suffix . "'";
+	}
+	else
+	{
+		//Insert new data into table.
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_ul" . $suffix . "', use_table_data=1, bkgd_opacity=" . $sub_level_background_opacity;
+	}
+	$cnt = $bwb_dbh->exec($query);
+	
 
 
 	/////////////////////////////////////////////
