@@ -13,6 +13,8 @@
 // Added table prefix handling.
 // Revised: 11/16/2012	ELL
 // Added checking for SSL and prompting if not SSL.
+// Revised: 7/1/2013	ELL
+// Implemented popup message class.
 // 
 //
 	include ("check_session.php");
@@ -40,78 +42,10 @@
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
 <link rel="stylesheet" href="manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
-<script language="javascript" type="text/javascript">
 
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#users", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-
-function DeleteConfirm()
-{
-	document.getElementById("delete_confirm").style.display = "block";
-	document.getElementById("delete_confirm").style.position = "absolute";
-	document.getElementById("delete_confirm").style.top = "200px";
-	document.getElementById("delete_confirm").style.left = "300px";
-	document.getElementById("delete_confirm").style.width = "450px";
-	document.getElementById("delete_confirm").style.backgroundColor = "#FFF";
-	document.getElementById("delete_confirm").style.borderStyle = "solid";
-	document.getElementById("delete_confirm").style.borderWidth = "2px";
-	document.getElementById("delete_confirm").style.borderColor = "#000";
-	document.getElementById("delete_text").innerHTML = document.getElementById("selectUserNameDelete").value;
-}
-
-function DeleteUser()
-{
-	var user_name = document.getElementById("selectUserNameDelete").value;
-	document.getElementById("delete_confirm").style.display = "none";
-	var url = "delete_user.php?user_name=" + user_name;
-	window.location = url;
-}
-
-function HideDelete()
-{
-	document.getElementById("delete_confirm").style.display = "none";
-}
-
-function GeneratePassword(source)
-{
-	var password = "";
-	var password_length = rand(6,10);
-	var i;
-	var assci_segment;
-	
-	for (i = 0; i < password_length; i++)
-	{
-		assci_segment = rand(1,3);
-		if (assci_segment == 1)
-			password = password + String.fromCharCode(rand(48,57));	// numeric
-		else if (assci_segment == 2)
-			password = password + String.fromCharCode(rand(65,90));	// alpha upper case
-		else
-			password = password + String.fromCharCode(rand(97,122));	// alpha lower case
-	}
-	password = password.replace('I', 'i');
-	password = password.replace('O', 'o');
-	password = password.replace('l', 'L');
-	
-	if (source == "new")
-		var frm_obj = document.getElementById ('password_new_user');
-	else
-		var frm_obj = document.getElementById ('password_existing_user');
-		
-	frm_obj.value = password;
-		
-	return password;
-}
-
-// Equivalent to PHP rand(min, max);
-function rand ( n, m )
-{
-  return ( n + Math.floor ( Math.random ( ) * (m - n + 1)) );
-}
-
-</script>
+<script type="text/javascript" src="js/mouse_position.js"></script>
+<script type="text/javascript" src="js/popup_msg.js"></script>
+<script type="text/javascript" src="js/users.js"></script>
 
 </head>
 
@@ -237,18 +171,10 @@ function rand ( n, m )
 </table>
 </div>
 
-<div id="delete_confirm">
-<table border="0" cellspacing="0" cellpadding="5" align="center">
-  <tr>
-    <td colspan="2">Are your sure you want to delete the user <b><div id="delete_text">&nbsp;</div></b>?</td>
-  </tr>
-  <tr>
-	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeleteUser();" /></td>
-	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();" />
-    </td>
-  </tr>
-</table>
-</div>
+<?php include("lib/popup_msg.html"); ?>
 
+<script language="javascript" type="text/javascript">
+	HidePopupMsg();
+</script>
 </body>
 </html>
